==> ec2-1.130.0-sources.jar: software/amazon/awscdk/services/ec2/GatewayVpcEndpoint.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A gateway VPC endpoint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.41.0 (build a274beb)", date = "2021-10-29T17:34:55.636Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.GatewayVpcEndpoint")
public class GatewayVpcEndpoint extends software.amazon.awscdk.services.ec2.VpcEndpoint implements software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint {

    protected GatewayVpcEndpoint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected GatewayVpcEndpoint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public GatewayVpcEndpoint(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param gatewayVpcEndpointId This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint fromGatewayVpcEndpointId(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String gatewayVpcEndpointId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.GatewayVpcEndpoint.class, "fromGatewayVpcEndpointId", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(gatewayVpcEndpointId, "gatewayVpcEndpointId is required") });
    }

    /**
     * The date and time the gateway VPC endpoint was created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVpcEndpointCreationTimestamp() {
        return software.amazon.jsii.Kernel.get(this, "vpcEndpointCreationTimestamp", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getVpcEndpointDnsEntries() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "vpcEndpointDnsEntries", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * The gateway VPC endpoint identifier.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVpcEndpointId() {
        return software.amazon.jsii.Kernel.get(this, "vpcEndpointId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getVpcEndpointNetworkInterfaceIds() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "vpcEndpointNetworkInterfaceIds", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.ec2.GatewayVpcEndpoint}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ec2.GatewayVpcEndpoint> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps.Builder();
        }

        /**
         * The service to use for this gateway VPC endpoint.
         * <p>
         * @return {@code this}
         * @param service The service to use for this gateway VPC endpoint. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder service(final software.amazon.awscdk.services.ec2.IGatewayVpcEndpointService service) {
            this.props.service(service);
            return this;
        }

        /**
         * Where to add endpoint routing.
         * <p>
         * By default, this endpoint will be routable from all subnets in the VPC.
         * Specify a list of subnet selection objects here to be more specific.
         * <p>
         * Default: - All subnets in the VPC
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>{@code
         * // Example automatically generated. See https://github.com/aws/jsii/issues/826
         * Vpc vpc;
         * vpc.addGatewayEndpoint("DynamoDbEndpoint", GatewayVpcEndpointOptions.builder()
         *         .service(ec2.GatewayVpcEndpointAwsService.DYNAMODB)
         *         // Add only to ISOLATED subnets
         *         .subnets(List.of(SubnetSelection.builder().subnetType(ec2.SubnetType.PRIVATE_ISOLATED).build()))
         *         .build());}</pre></blockquote>
         * <p>
         * @return {@code this}
         * @param subnets Where to add endpoint routing. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder subnets(final java.util.List<? extends software.amazon.awscdk.services.ec2.SubnetSelection> subnets) {
            this.props.subnets(subnets);
            return this;
        }

        /**
         * The VPC network in which the gateway endpoint will be used.
         * <p>
         * @return {@code this}
         * @param vpc The VPC network in which the gateway endpoint will be used. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpc(final software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.props.vpc(vpc);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ec2.GatewayVpcEndpoint}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.ec2.GatewayVpcEndpoint build() {
            return new software.amazon.awscdk.services.ec2.GatewayVpcEndpoint(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> ec2-1.131.0-sources.jar: software/amazon/awscdk/services/ec2/GatewayVpcEndpoint.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A gateway VPC endpoint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.42.0 (build 5f6b62c)", date = "2021-11-07T11:28:21.923Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.GatewayVpcEndpoint")
public class GatewayVpcEndpoint extends software.amazon.awscdk.services.ec2.VpcEndpoint implements software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint {

    protected GatewayVpcEndpoint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected GatewayVpcEndpoint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public GatewayVpcEndpoint(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param gatewayVpcEndpointId This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint fromGatewayVpcEndpointId(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String gatewayVpcEndpointId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.GatewayVpcEndpoint.class, "fromGatewayVpcEndpointId", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(gatewayVpcEndpointId, "gatewayVpcEndpointId is required") });
    }

    /**
     * The date and time the gateway VPC endpoint was created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVpcEndpointCreationTimestamp() {
        return software.amazon.jsii.Kernel.get(this, "vpcEndpointCreationTimestamp", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getVpcEndpointDnsEntries() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "vpcEndpointDnsEntries", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * The gateway VPC endpoint identifier.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getVpcEndpointId() {
        return software.amazon.jsii.Kernel.get(this, "vpcEndpointId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getVpcEndpointNetworkInterfaceIds() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "vpcEndpointNetworkInterfaceIds", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.ec2.GatewayVpcEndpoint}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ec2.GatewayVpcEndpoint> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps.Builder();
        }

        /**
         * The service to use for this gateway VPC endpoint.
         * <p>
         * @return {@code this}
         * @param service The service to use for this gateway VPC endpoint. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder service(final software.amazon.awscdk.services.ec2.IGatewayVpcEndpointService service) {
            this.props.service(service);
            return this;
        }

        /**
         * Where to add endpoint routing.
         * <p>
         * By default, this endpoint will be routable from all subnets in the VPC.
         * Specify a list of subnet selection objects here to be more specific.
         * <p>
         * Default: - All subnets in the VPC
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * // Example automatically generated. See https://github.com/aws/jsii/issues/826
         * Vpc vpc;
         * vpc.addGatewayEndpoint("DynamoDbEndpoint", GatewayVpcEndpointOptions.builder()
         *         .service(ec2.GatewayVpcEndpointAwsService.DYNAMODB)
         *         // Add only to ISOLATED subnets
         *         .subnets(List.of(SubnetSelection.builder().subnetType(ec2.SubnetType.PRIVATE_ISOLATED).build()))
         *         .build());
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param subnets Where to add endpoint routing. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder subnets(final java.util.List<? extends software.amazon.awscdk.services.ec2.SubnetSelection> subnets) {
            this.props.subnets(subnets);
            return this;
        }

        /**
         * The VPC network in which the gateway endpoint will be used.
         * <p>
         * @return {@code this}
         * @param vpc The VPC network in which the gateway endpoint will be used. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpc(final software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.props.vpc(vpc);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ec2.GatewayVpcEndpoint}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.ec2.GatewayVpcEndpoint build() {
            return new software.amazon.awscdk.services.ec2.GatewayVpcEndpoint(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
